==> data-driven-motion-0.0.2.tgz: package/README.md <==
# data-driven-motion

[![npm version](https://badge.fury.io/js/data-driven-motion.svg)](https://badge.fury.io/js/data-driven-motion)
[![Build Status](https://travis-ci.org/tkh44/data-driven-motion.svg?branch=master)](https://travis-ci.org/tkh44/data-driven-motion)
[![codecov](https://codecov.io/gh/tkh44/data-driven-motion/branch/master/graph/badge.svg)](https://codecov.io/gh/tkh44/data-driven-motion)



Easily animate your data in react

This is a small wrapper around [react-motion](https://github.com/chenglou/react-motion) with the intention of simplifying the api for my most common use case.


```bash
npm install -S data-driven-motion
```

## Motion

```jsx
<Motion
  data={[]}
  component={<ul style={{ padding: 8 }} />}
  render={(key, data, style) => <li key={key} style={style}>{data.name}</li>}
  getKey={data => data.name}
  onComponentMount={data => ({ top: data.top, left: data.left })}
  onRender={(data, i, spring) => ({ top: spring(data.top), left: spring(data.left) })}
  onRemount={({ data }) => ({ top: data.top - 32, left: data.left - 32 })}
  onUnmount={({ data }, spring) => ({ top: spring(data.top + 32), left: spring(data.left + 32) })}
/>
```

### Props

#### component: `PropTypes.element`
wrapper element 
ex: `<div/>`


#### data: `PropTypes.array`
array of data


#### render: `PropTypes.oneOfType([PropTypes.func, PropTypes.arrayOf(PropTypes.func)])`
`(key, data, style) => ReactElement`

called once render for each item in `data` with the key from `getKey`, `data` from `data[index]`, and
`style`, the result of: `onComponentMount`, `onRender`, `onRemount`, or `onUnmount`

If an array is provided it will render the resulting elements in order.
This is useful for creating animated layers.


#### getKey: `PropTypes.func`
`(data, i) => string`

help identify which items have been changed, added, or are removed
https://facebook.github.io/react/docs/lists-and-keys.html


#### onComponentMount: `PropTypes.func`
`(data, i) => Style object`

`data === props.data[i]`

called when `component` mounts
do not wrap values in springs


#### onRender: `PropTypes.func`
`(data, i, spring) => Style object`

`data === props.data[i]`

called when `component` mounts
do not wrap values in springs


#### onRemount: `PropTypes.func`

`({ key, data, style }) => Style object`

*Notice the argument is wrapped in an object*

The argument is the computed config from `onRender` 

do not wrap values in springs


#### onUnmount: `PropTypes.func`

`({ key, data, style }) => Style object`

*Notice the argument is wrapped in an object*

The argument is the computed config from `onRender`

do not wrap values in springs


### Example
```javascript
import { createElement as h, Component } from 'react'
import { Motion } from 'data-driven-motion'

export default class ListWrapper extends Component {
  render () {
    return h(Motion, {
      data: this.props.data,
      component: <ul />,
      getKey: data => data.name,
      onComponentMount: data => {
        // no springs
        return {
          top: data.top,
          left: data.left,
          opacity: data.top > 500 ? 0 : 1,
          translateY: data.offsetY
        }
      },
      onRender: (data, i) => {
        // springs
        return {
          top: spring(i * data.top),
          left: spring(data.left),
          opacity: data.top > 500 ? 0 : 1, // you don't have to use them,
          translateY: spring(data.offsetY)
        }
      },
      onRemount: ({key, data, style}) => {
        // no springs
        // key, data, style come from the config generated by `onRender`.
        // When the piece of data is remounted this function is called to override the initial position of the rendered element
        // We are creating a starting point to our animation here
        // *from* onRemount styles *to* onRender styles
        // be careful using values from `style` they will be `spring` objects
        return {
          top: data.top,
          left: data.left,
          opacity: data.top > 500 ? 0 : 1,
          translateY: data.offsetY
        }
      },
      onUnmount: ({key, data, style}, i, spring) => {
        // springs
        // Where to animate *to* when removing this data item
        return {
          top: spring(data.top),
          left: spring(data.left),
          opacity: data.top > 500 ? 0 : 1, // you don't have to use them,
          translateY: spring(data.offsetY)
        }
      },
      render: (key, data, style) => {
        // called for each data item with its key, data and style
        return (
          <li
            key={key}
            style={{
              position: 'absolute',
              top: style.top,
              left: style.left,
              opacity: style.opacity,
              transform: `translateY(${style.translateY})`
            }}
            onClick={this.handleClick.bind(this, key, data, style)}
          >
            {data.name} | { data.username}
          </li>
        )
      }
    })
  }
}
```

==> data-driven-motion-0.0.4.tgz: package/README.md <==
# data-driven-motion

[![npm version](https://badge.fury.io/js/data-driven-motion.svg)](https://badge.fury.io/js/data-driven-motion)
[![Build Status](https://travis-ci.org/tkh44/data-driven-motion.svg?branch=master)](https://travis-ci.org/tkh44/data-driven-motion)
[![codecov](https://codecov.io/gh/tkh44/data-driven-motion/branch/master/graph/badge.svg)](https://codecov.io/gh/tkh44/data-driven-motion)
[![Standard - JavaScript Style Guide](https://img.shields.io/badge/code_style-standard-brightgreen.svg)](https://img.shields.io/badge/code_style-standard-brightgreen.svg)



Easily animate your data in react

This is a small wrapper around [react-motion](https://github.com/chenglou/react-motion) with the intention of simplifying the api for my most common use case.


```bash
npm install -S data-driven-motion
```

## Motion

```jsx
<Motion
  data={[]}
  component={<ul style={{ padding: 8 }} />}
  render={(key, data, style) => <li key={key} style={style}>{data.name}</li>}
  getKey={data => data.name}
  onComponentMount={data => ({ top: data.top, left: data.left })}
  onRender={(data, i, spring) => ({ top: spring(data.top), left: spring(data.left) })}
  onRemount={({ data }) => ({ top: data.top - 32, left: data.left - 32 })}
  onUnmount={({ data }, spring) => ({ top: spring(data.top + 32), left: spring(data.left + 32) })}
/>
```

**It does not matter what `data` contains, as long as it is an array**



### Props

#### component: `PropTypes.element`
wrapper element 
ex: `<div/>`


#### data: `PropTypes.array`
array of data


#### render: `PropTypes.oneOfType([PropTypes.func, PropTypes.arrayOf(PropTypes.func)])`
`(key, data, style) => ReactElement`

called on render for each item in `data` with the `key` from `getKey`, `data` from `data[index]`, and
`style`, the result of: `onComponentMount`, `onRender`, `onRemount`, or `onUnmount`

If an array is provided it will render the resulting elements in order.
This is useful for creating animated layers.


#### getKey: `PropTypes.func`
`(data, i) => string`

help identify which items have been changed, added, or are removed
https://facebook.github.io/react/docs/lists-and-keys.html


#### onComponentMount: `PropTypes.func`
`(data, i) => Style object`

`data === props.data[i]`

called when `component` mounts

__do not wrap values in springs__


#### onRender: `PropTypes.func`
`(data, i, spring) => Style object`

`data === props.data[i]`

called when `props.component` mounts

__ok to wrap values in springs__


#### onRemount: `PropTypes.func`

`({ key, data, style }) => Style object`

*Notice the argument is wrapped in an object*

The argument is the computed config from `onRender` 

__do not wrap values in springs__


#### onUnmount: `PropTypes.func`

`({ key, data, style }) => Style object`

*Notice the argument is wrapped in an object*

The argument is the computed config from `onRender`. 

__ok to wrap values in springs__


### Single Element Entry/Exit
```jsx
<Motion
  data={this.state.show ? [this.props] : []}
  component={<div style={{ padding: 8 }} />}
  render={(key, data, style) => <div key={key} style={style} {...data} />}
  getKey={(data, i) => i}
  onComponentMount={()) => ({ opacity: 0 })}
  onRender={(data, i, spring) => ({ opacity: spring(1) })}
  onRemount={() => ({ opacity: 0 })}
  onUnmount={(config, spring) => ({ opacity: spring(0) })}
/>
```

### List Example
```javascript
import { createElement as h, Component } from 'react'
import { Motion } from 'data-driven-motion'

export default class ListWrapper extends Component {
  render () {
    return h(Motion, {
      data: this.props.data,
      component: <ul />,
      getKey: data => data.name,
      onComponentMount: data => {
        // no springs
        return {
          top: data.top,
          left: data.left,
          opacity: data.top > 500 ? 0 : 1,
          translateY: data.offsetY
        }
      },
      onRender: (data, i) => {
        // springs
        return {
          top: spring(i * data.top),
          left: spring(data.left),
          opacity: data.top > 500 ? 0 : 1, // you don't have to use them,
          translateY: spring(data.offsetY)
        }
      },
      onRemount: ({key, data, style}) => {
        // no springs
        // key, data, style come from the config generated by `onRender`.
        // When the piece of data is remounted this function is called to override the initial position of the rendered element
        // We are creating a starting point to our animation here
        // *from* onRemount styles *to* onRender styles
        // be careful using values from `style` they will be `spring` objects
        return {
          top: data.top,
          left: data.left,
          opacity: data.top > 500 ? 0 : 1,
          translateY: data.offsetY
        }
      },
      onUnmount: ({key, data, style}, i, spring) => {
        // springs
        // Where to animate *to* when removing this data item
        return {
          top: spring(data.top),
          left: spring(data.left),
          opacity: data.top > 500 ? 0 : 1, // you don't have to use them,
          translateY: spring(data.offsetY)
        }
      },
      render: (key, data, style) => {
        // called for each data item with its key, data and style
        return (
          <li
            key={key}
            style={{
              position: 'absolute',
              top: style.top,
              left: style.left,
              opacity: style.opacity,
              transform: `translateY(${style.translateY})`
            }}
            onClick={this.handleClick.bind(this, key, data, style)}
          >
            {data.name} | { data.username}
          </li>
        )
      }
    })
  }
}
```
